@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -46,6 +46,13 @@ has scale => (
 );
 
 
+has tonic => (
+    is      => 'ro',
+    isa     => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
+    default => sub { 0 },
+);
+
+
 has verbose => (
     is  => 'ro',
     isa => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
@@ -141,20 +148,6 @@ sub generate {
     # Make sure there are no duplicate pitches
     @fixed = uniq @fixed;
 
-    # Intersect with the next chord pitches
-    my @intersect;
-    if ($next_chord) {
-        my $A1 = Set::Array->new(@fixed);
-        my $A2 = Set::Array->new(@next_pitches);
-        @intersect = @{ $A1->intersection($A2) };
-        # DEBUGGING:
-        my @named;
-        if ($self->verbose) {
-            @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @intersect;
-            print "\tINTERSECT: ",ddc(\@named);
-        }
-    }
-
     # DEBUGGING:
     my @named;
     if ($self->verbose) {
@@ -167,14 +160,23 @@ sub generate {
         intervals => $self->intervals,
     );
 
-    # Try to start in the middle of the range
-    $voice->context($fixed[int @fixed / 2]);
-
-    # Choose Or Die!!
+    # Get a passage of quasi-random pitches
     my @chosen = map { $voice->rand } 1 .. $num;
 
-    # Lead to the next chord
-    if (@intersect) {
+    $chosen[0] = $fixed[0] if $self->tonic;
+
+    # Intersect with the next-chord pitches
+    my @intersect;
+    if ($next_chord) {
+        my $A1 = Set::Array->new(@fixed);
+        my $A2 = Set::Array->new(@next_pitches);
+        @intersect = @{ $A1->intersection($A2) };
+        # DEBUGGING:
+        if ($self->verbose) {
+            my @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @intersect;
+            print "\tINTERSECT: ",ddc(\@named);
+        }
+        # Lead to the next chord
         $chosen[-1] = $intersect[int rand @intersect];
     }
 
@@ -201,7 +203,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -278,6 +280,15 @@ second walks either the major or minor pentatonic scale, plus the
 notes of the chord.  The last walks only the notes of the chord (no
 scale).
 
+=head2 tonic
+
+  $tonic = $bassline->tonic;
+
+Play the first note of the scale on the first note of the generated
+phrase.
+
+Default: C<0>
+
 =head2 verbose
 
   $verbose = $bassline->verbose;
